@@ -2519,6 +2519,9 @@ doProcess <- function(options)
 		}
 	}
 
+	
+	write("starting analysis...", stderr())
+
 	#make some check here, because this file is being readed in chronojump
 
 	#write(paste("(4/5)",translate("Repetitions processed")), op$OutputData2)
@@ -2937,10 +2940,10 @@ doProcess <- function(options)
 		if(op$Analysis == "curves" || writeCurves) {
 			#this columns are going to be removed from paf:
 
-			write("paf and pafCurves", stderr())
-			write(paf$meanSpeed, stderr())
+			#write("paf and pafCurves", stderr())
+			#write(paf$meanSpeed, stderr())
 			pafCurves <- subset( paf, select = -c(mass, massBody, massExtra, inertiaMomentum) )
-			write(pafCurves$meanSpeed, stderr())
+			#write(pafCurves$meanSpeed, stderr())
 
 
 			if(singleFile)
@@ -3084,6 +3087,7 @@ doProcess <- function(options)
 	print("Creating (op$OutputData2)5.txt with touch method...")
 	file.create(paste(op$OutputData2,"5.txt",sep=""))
 	print("Created")
+	write("created ...5.txt", stderr())
 
 	warnings()
 }
