@@ -150,13 +150,19 @@ public class ExportSession
 	protected virtual void getData() 
 	{
 		myPersonsAndPS = SqlitePersonSession.SelectCurrentSessionPersons(mySession.UniqueID, true);
-		myJumps= SqliteJump.SelectJumps(false, mySession.UniqueID, -1, "", "");
-		myJumpsRj = SqliteJumpRj.SelectJumps(mySession.UniqueID, -1, "", "");
-		myRuns= SqliteRun.SelectRuns(false, mySession.UniqueID, -1, "");
-		myRunsInterval = SqliteRunInterval.SelectRuns(mySession.UniqueID, -1, "");
-		myReactionTimes = SqliteReactionTime.SelectReactionTimes(false, mySession.UniqueID, -1);
-		myPulses = SqlitePulse.SelectPulses(mySession.UniqueID, -1);
-		myMCs = SqliteMultiChronopic.SelectTests(mySession.UniqueID, -1);
+
+		//Leave SQL opened in all this process
+		Sqlite.Open(); // ------------------------------
+		
+		myJumps= SqliteJump.SelectJumps(true, mySession.UniqueID, -1, "", "");
+		myJumpsRj = SqliteJumpRj.SelectJumps(true, mySession.UniqueID, -1, "", "");
+		myRuns= SqliteRun.SelectRuns(true, mySession.UniqueID, -1, "");
+		myRunsInterval = SqliteRunInterval.SelectRuns(true, mySession.UniqueID, -1, "");
+		myReactionTimes = SqliteReactionTime.SelectReactionTimes(true, mySession.UniqueID, -1);
+		myPulses = SqlitePulse.SelectPulses(true, mySession.UniqueID, -1);
+		myMCs = SqliteMultiChronopic.SelectTests(true, mySession.UniqueID, -1);
+		
+		Sqlite.Close(); // ------------------------------
 	}
 
 	protected virtual void printTitles(string title) {
@@ -222,7 +228,7 @@ public class ExportSession
 				Catalog.GetString ("Sex") + ":" + Catalog.GetString ("Date of Birth") + ":" +
 				Catalog.GetString ("Description") + ":" + 
 				Catalog.GetString ("Height") + ":" + Catalog.GetString("Weight") + ":" +
-				Catalog.GetString ("Sport") + ":" + Catalog.GetString("Speciallity") + ":" +
+				Catalog.GetString ("Sport") + ":" + Catalog.GetString("Specialty") + ":" +
 				Catalog.GetString ("Level") + ":" + Catalog.GetString ("Comments")
 			   );
 
