@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -47,21 +47,28 @@ class SqliteEvent : Sqlite
 		dbcmd.ExecuteNonQuery();
 	}
 	
-	public static int GraphLinkInsert(string tableName, string eventName, string graphFileName, bool dbconOpened)
+	//called from some Chronojump methods
+	//adds dbcmd to be used on next Insert method
+	public static int GraphLinkInsert(string tableName, string eventName, string graphFileName, bool dbconOpened) 
+	{
+		return GraphLinkInsert(tableName, eventName, graphFileName, dbconOpened, dbcmd);
+	}
+	//Called from initialize jump, jumpRj
+	public static int GraphLinkInsert(string tableName, string eventName, string graphFileName, bool dbconOpened, SqliteCommand mycmd)
 	{
 		if(! dbconOpened) {
 			Sqlite.Open();
 		}
-		dbcmd.CommandText = "INSERT INTO graphLinkTable" + 
+		mycmd.CommandText = "INSERT INTO graphLinkTable" + 
 				"(uniqueID, tableName, eventName, graphFileName, other1, other2)" +
 				" VALUES (NULL, '" + tableName + "', '" + eventName + "', '" + graphFileName + "', '', '')" ;
-		Log.WriteLine(dbcmd.CommandText.ToString());
-		dbcmd.ExecuteNonQuery();
+		LogB.SQL(mycmd.CommandText.ToString());
+		mycmd.ExecuteNonQuery();
 		//int myLast = dbcon.LastInsertRowId;
 		//http://stackoverflow.com/questions/4341178/getting-the-last-insert-id-with-sqlite-net-in-c
 		string myString = @"select last_insert_rowid()";
-		dbcmd.CommandText = myString;
-		int myLast = Convert.ToInt32(dbcmd.ExecuteScalar()); // Need to type-cast since `ExecuteScalar` returns an object.
+		mycmd.CommandText = myString;
+		int myLast = Convert.ToInt32(mycmd.ExecuteScalar()); // Need to type-cast since `ExecuteScalar` returns an object.
 		if(! dbconOpened) {
 			Sqlite.Close();
 		}
@@ -76,7 +83,7 @@ class SqliteEvent : Sqlite
 
 		dbcmd.CommandText = "SELECT graphFileName FROM graphLinkTable WHERE tableName == '" + tableName + "' AND eventName =='" + eventName + "'";
 		
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		SqliteDataReader reader;
@@ -101,7 +108,7 @@ class SqliteEvent : Sqlite
 
 		dbcmd.CommandText = "UPDATE " + tableName + " SET simulated = " + simulated + 
 			" WHERE uniqueID == " + uniqueID ;
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		if(!dbconOpened)
@@ -114,7 +121,7 @@ class SqliteEvent : Sqlite
 	{
 		dbcmd.CommandText = "UPDATE " + tableName + " SET simulated = -1" + 
 			" WHERE simulated == 1";
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 	}
 	public static void SimulatedConvertToNegative() 
