@@ -72,6 +72,7 @@ class Sqlite
 	protected static int conversionSubRateTotal;
 
 	public static bool IsOpened = false;
+	public static bool SafeClose = true;
 
 	/*
 	 * Important, change this if there's any update to database
@@ -100,22 +101,32 @@ class Sqlite
 		} catch {
 			LogB.SQL("-- catched --");
 
-			LogB.SQLoff();
-			dbcon.Close();
-			
+			Close();
+
+			LogB.Warning(" going to open ");
 			LogB.SQLon();
 			dbcon.Open();
 			
 			LogB.SQL("-- end of catched --");
 		}
-
+		
 		IsOpened = true;
 	}
 	public static void Close()
 	{
 		LogB.SQLoff();
+			
+		if(SafeClose) {
+			dbcmd.Dispose(); //this seems critical in multiple open/close SQL
+		}
+
 		dbcon.Close();
 		
+		if(SafeClose) {
+			//GC.Collect(); don't need and very slow
+			dbcmd = dbcon.CreateCommand();
+		}
+		
 		IsOpened = false;
 	}
 
